summaryrefslogtreecommitdiff
path: root/cmake/loop-darwin.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/loop-darwin.cmake')
-rw-r--r--cmake/loop-darwin.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmake/loop-darwin.cmake b/cmake/loop-darwin.cmake
index ef79eef01b..a330375653 100644
--- a/cmake/loop-darwin.cmake
+++ b/cmake/loop-darwin.cmake
@@ -1,5 +1,5 @@
-# Modify platform/darwin/loop-files.txt to change the source files for this target.
-load_sources_list(MBGL_LOOP_DARWIN_FILES platform/darwin/loop-files.txt)
+# Modify platform/darwin/loop-files.json to change the source files for this target.
+load_sources_list(MBGL_LOOP_DARWIN_FILES platform/darwin/loop-files.json)
add_library(mbgl-loop-darwin STATIC ${MBGL_LOOP_DARWIN_FILES})
target_include_directories(mbgl-loop-darwin